@@ -11,11 +11,17 @@ class ResultModel:
         return "success:%s,data:%s,message:%s" % (self.success,self.data,self.message)
 
     def to_json(self):
-        return json.dumps(self.__dict__())
+        return json.dumps(self.to_dict())
+
+    def to_dict(self):
+        data_dict = self.data
+        if self.data:
+            if hasattr(self.data, "to_dict"):
+                data_dict = self.data.to_dict()
+        return {
+            "success": self.success,
+            "data": data_dict,
+            "message": self.message
+        }
+
 
-    def __dict__(self):
-        return  {
-            "success":self.success,
-            "data": self.data,
-            "message":self.message
-        }
\ No newline at end of file
